import { Fragment as _Fragment, jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from "react";
import { useStore } from "@react-nano/redux";
/**
 * The DynamicModuleLoader adds a way to register a module on mount
 * When this component is initialized, the reducer and saga from the module passed as props will be registered with the system
 * On unmount, they will be unregistered
 */
export const DynamicModuleLoader = ({ modules, children }) => {
    const store = useStore();
    const [active, setActive] = useState(false);
    useEffect(() => {
        const added = store.addModules(modules);
        setActive(true);
        return () => added.remove();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [store]);
    // eslint-disable-next-line react/jsx-no-useless-fragment
    return active ? _jsx(_Fragment, { children: children }) : null;
};
